library photo_editor_pro;

import 'dart:typed_data';
import 'package:flutter/material.dart';
import 'package:image_gallery_saver/image_gallery_saver.dart';
import 'package:intl/intl.dart';
import 'package:photo_editor_pro/view/edit_view.dart';

class ImageEditorPage extends StatefulWidget {
  final List<Uint8List?> imageDataList;
  const ImageEditorPage(this.imageDataList, {super.key});

  @override
  State<ImageEditorPage> createState() => _ImageEditorPageState();
}

class _ImageEditorPageState extends State<ImageEditorPage> {
  String? path;
  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: Colors.black,
      appBar: AppBar(
        leading: IconButton(onPressed: () {
          Navigator.pop(context);
        },
            icon:const Icon(Icons.arrow_back_outlined,color: Colors.white) ),
        backgroundColor: Colors.black,
        title: const Text("Image Editor",style: TextStyle(color: Colors.white),),
        actions: [
          IconButton(onPressed: () {
            if (path == null) {
              ScaffoldMessenger.of(context).showSnackBar(
                SnackBar(content: Text("Please download the image first")),
              );
            } else {
              setState(() {});
              ScaffoldMessenger.of(context).showSnackBar(
                SnackBar(content: Text("Image path $path")),
              );
              Navigator.pop(context);
            }
          }, icon: Icon(Icons.save_outlined))
        ],
      ),
      body: SingleChildScrollView(
        child: Column(
          mainAxisAlignment: MainAxisAlignment.center,
          children: [
            for (var imageData in widget.imageDataList)
              if (imageData != null) Image.memory(imageData),
            const SizedBox(height: 16),
            ElevatedButton(
              child: const Text("Start editing"),
              onPressed: () async {
                var editedImage = await Navigator.push(
                  context,
                  MaterialPageRoute(
                    builder: (context) => ImageEditorNew(
                      image: widget.imageDataList.isNotEmpty ? widget.imageDataList.first : null,
                    ),
                  ),
                );

                // replace with edited image
                if (editedImage != null) {
                  widget.imageDataList[0] = editedImage;
                  setState(() {});
                }
              },
            ),
            ElevatedButton(
              child: const Text("Download Image"),
              onPressed: () async {
                // Assuming imageDataList has at least one image
                if (widget.imageDataList.isNotEmpty && widget.imageDataList[0] != null) {
                  await saveImage(widget.imageDataList[0]!);
                }
              },
            ),
            const SizedBox(height: 30),
          ],
        ),
      ),
    );
  }

  Future<void> saveImage(Uint8List imageData) async {
    final now = DateTime.now();
    final formattedDate = DateFormat('yyyy-MM-dd_HH-mm-ss').format(now);
    final fileName = 'image_$formattedDate.png'; // Example file name: image_2024-03-27_15-30-45.png

    final result = await ImageGallerySaver.saveImage(imageData, name: fileName);
    if (result['isSuccess']) {
      ScaffoldMessenger.of(context).showSnackBar(
        SnackBar(content: Text("Image saved successfully as $fileName")),
      );
      setState(() {});
      path=fileName;
      print("Image saved as: $fileName");
    } else {
      ScaffoldMessenger.of(context).showSnackBar(
        SnackBar(content: Text("Failed to save image")),
      );
    }
  }


}
